==> milton-server-ce-2.7.1.5-sources.jar: io/milton/ftp/UserService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package io.milton.ftp;

/**
 *
 * @author brad
 */
public interface UserService {

    /**
     * don't need it
     *
     * @param name
     */
    public void delete( String name );

    /**
     * * don't need it
     *
     * @param name
     * @return
     */
    public boolean doesExist( String name );

    /**
     * * don't need it
     *
     * @return
     */
    public String[] getAllUserNames();

    /**
     *
     * @param name - milton form of the username E.g. user@authority
     * @param domain - the domain to login into
     * @return
     */
    public MiltonUser getUserByName( String name, String domain );

    /**
     * Save the user. You don't need to implement this
     * @param user
     */
    public void save( MiltonUser user );

}

==> milton-server-ce-3.1.0.301-sources.jar: io/milton/ftp/UserService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package io.milton.ftp;

/**
 *
 * @author brad
 */
public interface UserService {

    /**
     * don't need it
     *
     * @param name
     */
    void delete(String name);

    /**
     * * don't need it
     *
     * @param name
     * @return
     */
    boolean doesExist(String name);

    /**
     * * don't need it
     *
     * @return
     */
    String[] getAllUserNames();

    /**
     *
     * @param name - milton form of the username E.g. user@authority
     * @param domain - the domain to login into
     * @return
     */
    MiltonUser getUserByName(String name, String domain);

    /**
     * Save the user. You don't need to implement this
     * @param user
     */
    void save(MiltonUser user);

}
